@@ -7,10 +7,12 @@
 import os
 import sys
 import time
+from fast_tracker import config
 
-startup_debug = os.environ.get("FastTracker_Debug", "off").lower() in ("on", "true", "1")
-fast_debug_level = int(os.environ.get("FastTracker_Debug_Level", "0"))
-
+startup_debug = os.environ.get("FastTracker.Debug", "off").lower() in ("on", "true", "1")
+fast_debug_level = int(os.environ.get("FastTracker.Debug.Level", "0"))
+if config.get_logging_level() == "ERROR":
+    fast_debug_level = 0
 
 def log_message(text, *args, level=1):
     if startup_debug:
