@@ -37,7 +37,7 @@ def log(text, *args, level=1):
     if config.tracker_logging.get("Level"):
         text = text % args
         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-        sys.stdout.write("FAST: %s - %s@%s:%s\n" % (timestamp, __file__, sys._getframe().f_lineno, text))
+        sys.stdout.write("FAST: %s - %s\n" % (timestamp, text))
         sys.stdout.flush()
 
 
